Bug 1444162 - Replace 'Cancel Setup' string with 'Remove Account' r?eoger draft
authorThom Chiovoloni <tchiovoloni@mozilla.com>
Mon, 19 Mar 2018 10:38:59 -0700
changeset 769479 0263924a0a7eee35bbaa76d144c9edb89431fd60
parent 769320 4f1014eb5039bdfdd7a39fb7785d102df1994a6f
push id103144
push userbmo:tchiovoloni@mozilla.com
push dateMon, 19 Mar 2018 17:39:19 +0000
reviewerseoger
bugs1444162
milestone61.0a1
Bug 1444162 - Replace 'Cancel Setup' string with 'Remove Account' r?eoger MozReview-Commit-ID: A99nssZ1Dpz
browser/components/preferences/in-content/sync.xul
browser/components/preferences/in-content/tests/browser_search_within_preferences_2.js
browser/locales/en-US/chrome/browser/preferences/sync.dtd
--- a/browser/components/preferences/in-content/sync.xul
+++ b/browser/components/preferences/in-content/sync.xul
@@ -103,17 +103,17 @@
                   <description flex="1">
                     &signedInUnverified.beforename.label;
                     <label class="fxaEmailAddress"/>
                     &signedInUnverified.aftername.label;
                   </description>
                 </hbox>
                 <hbox class="fxaAccountBoxButtons">
                   <button id="verifyFxaAccount" label="&resendVerification.label;" accesskey="&resendVerification.accesskey;"></button>
-                  <button id="unverifiedUnlinkFxaAccount" label="&cancelSetup.label;" accesskey="&cancelSetup.accesskey;"></button>
+                  <button id="unverifiedUnlinkFxaAccount" label="&removeAccount.label;" accesskey="&removeAccount.accesskey;"></button>
                 </hbox>
               </vbox>
             </hbox>
 
             <!-- logged in locally but server rejected credentials -->
             <hbox id="fxaLoginRejected">
               <vbox>
                 <image class="fxaProfileImage"/>
@@ -124,17 +124,17 @@
                   <description flex="1">
                     &signedInLoginFailure.beforename.label;
                     <label class="fxaEmailAddress"/>
                     &signedInLoginFailure.aftername.label;
                   </description>
                 </hbox>
                 <hbox class="fxaAccountBoxButtons">
                   <button id="rejectReSignIn" label="&signIn.label;" accesskey="&signIn.accesskey;"></button>
-                  <button id="rejectUnlinkFxaAccount" label="&cancelSetup.label;" accesskey="&cancelSetup.accesskey;"></button>
+                  <button id="rejectUnlinkFxaAccount" label="&removeAccount.label;" accesskey="&removeAccount.accesskey;"></button>
                 </hbox>
               </vbox>
             </hbox>
           </deck>
         </groupbox>
         <groupbox id="syncOptions">
           <caption><label>&signedIn.settings.label;</label></caption>
           <description>&signedIn.settings.description;</description>
--- a/browser/locales/en-US/chrome/browser/preferences/sync.dtd
+++ b/browser/locales/en-US/chrome/browser/preferences/sync.dtd
@@ -67,18 +67,18 @@ both, to better adapt this sentence to t
 <!ENTITY signIn.accesskey             "g">
 <!ENTITY profilePicture.tooltip       "Change profile picture">
 <!ENTITY verifiedManage.label         "Manage account">
 <!ENTITY verifiedManage.accesskey     "o">
 <!ENTITY disconnect3.label            "Disconnect…">
 <!ENTITY disconnect3.accesskey        "D">
 <!ENTITY resendVerification.label     "Resend Verification">
 <!ENTITY resendVerification.accesskey "d">
-<!ENTITY cancelSetup.label            "Cancel Setup">
-<!ENTITY cancelSetup.accesskey        "p">
+<!ENTITY removeAccount.label          "Remove Account">
+<!ENTITY removeAccount.accesskey      "p">
 
 <!ENTITY signedOut.caption            "Take Your Web With You">
 <!ENTITY signedOut.description        "Synchronize your bookmarks, history, tabs, passwords, add-ons, and preferences across all your devices.">
 <!ENTITY signedOut.accountBox.title   "Connect with a &syncBrand.fxAccount.label;">
 <!ENTITY signedOut.accountBox.create2 "Don’t have an account? Get started">
 <!ENTITY signedOut.accountBox.create2.accesskey "C">
 <!ENTITY signedOut.accountBox.signin2 "Sign In…">
 <!ENTITY signedOut.accountBox.signin2.accesskey "I">
--- a/browser/components/preferences/in-content/tests/browser_search_within_preferences_2.js
+++ b/browser/components/preferences/in-content/tests/browser_search_within_preferences_2.js
@@ -7,18 +7,18 @@
  * Enabling searching functionality. Will display search bar from this testcase forward.
  */
 add_task(async function() {
   await SpecialPowers.pushPrefEnv({"set": [["browser.preferences.search", true]]});
 });
 
 /**
  * Test that we only search the selected child of a XUL deck.
  * When we search "Cancel Setup",
  * it should not show the "Cancel Setup" button if the Firefox account is not logged in yet.
  */
 add_task(async function() {
   await openPreferencesViaOpenPreferencesAPI("paneGeneral", {leaveOpen: true});
 
   // Ensure the "Sign Up" button in the hidden child of the <xul:deck>
   // is selected and displayed on the screen.
   let weavePrefsDeck = gBrowser.contentDocument.getElementById("weavePrefsDeck");
   is(weavePrefsDeck.selectedIndex, 0, "Should select the #noFxaAccount child node");
@@ -43,23 +43,23 @@ add_task(async function() {
     if (child.id == "header-searchResults" ||
         child.id == "weavePrefsDeck") {
       is_element_visible(child, "Should be in search results");
     } else if (child.id) {
       is_element_hidden(child, "Should not be in search results");
     }
   }
 
   // Ensure the "Cancel Setup" button exists in the hidden child of the <xul:deck>.
   let unlinkFxaAccount = weavePrefsDeck.childNodes[1].querySelector("#unverifiedUnlinkFxaAccount");
-  is(unlinkFxaAccount.label, "Cancel Setup", "The Cancel Setup button should exist");
+  is(unlinkFxaAccount.label, "Remove Account", "The Remove Account button should exist");
 
   // Performs search.
   searchInput.focus();
-  query = "Cancel Setup";
+  query = "Remove Account";
   searchCompletedPromise = BrowserTestUtils.waitForEvent(
       gBrowser.contentWindow, "PreferencesSearchCompleted", evt => evt.detail == query);
   EventUtils.sendString(query);
@@ -7,18 +7,18 @@
 /**
  * Test that we only search the selected child of a XUL deck.
- * When we search "Cancel Setup",
- * it should not show the "Cancel Setup" button if the Firefox account is not logged in yet.
+ * When we search "Remove Account",
+ * it should not show the "Remove Account" button if the Firefox account is not logged in yet.
  */
 add_task(async function() {
@@ -43,23 +43,23 @@ add_task(async function() {
   }
 
-  // Ensure the "Cancel Setup" button exists in the hidden child of the <xul:deck>.
+  // Ensure the "Remove Account" button exists in the hidden child of the <xul:deck>.
   let unlinkFxaAccount = weavePrefsDeck.childNodes[1].querySelector("#unverifiedUnlinkFxaAccount");
   await searchCompletedPromise;
 
   let noResultsEl = gBrowser.contentDocument.querySelector(".no-results-message");
   is_element_visible(noResultsEl, "Should be reporting no results");
 